>From 33e51a382086e9ab00bf55ccf3958f87354f428f Mon Sep 17 00:00:00 2001
From: Richard Hemzal <hemzal@asm.cz>
Date: Tue, 10 Jan 2012 16:00:34 +0100
Subject: [PATCH] Solution for some DVB-S2 cards which not working under dvblast when tuning QPSK

It looks is necessary to differ between QPSK for DVB-S and DVB-S2
I met issue that TBS6984 is not able to tune DVB-S when defined as DVB-S2
Probably issue thanks to predefine DTV_DELIVERY_SYSTEM=DVB-S2
Yes some other cards TBS6928 does not have this issue but in fact is quite
logical that delivery system can be defined by parameters for cards which
cannot find out on which system are trying to make lock.

Identification by just modulation m=QPSK looks not to be ok
There are DVB-S2 transponders running in QPKS and also running in 8PSK so this parameter
can tell which system it is if card cannot recognize self.

As this I suggest to use presence of ROLLOFF as indication that transponder is intended to be DVB-S2
So dvblast -R -1  or any -R xx value will confirm that must be DVB-S2 used
---
 dvb.c     |   10 +++++-----
 dvblast.1 |    2 +-
 dvblast.c |    3 +++
 dvblast.h |    1 +
 4 files changed, 10 insertions(+), 6 deletions(-)

diff --git a/dvb.c b/dvb.c
index 557b7d3..0b87e63 100644
--- a/dvb.c
+++ b/dvb.c
@@ -79,7 +79,7 @@ void dvb_Open( void )
 {
     char psz_tmp[128];
 
-    msg_Dbg( NULL, "using linux-dvb API version %d", DVB_API_VERSION );
+    msg_Dbg( NULL, "using linux-dvb API version %d.%d", DVB_API_VERSION, DVB_API_VERSION_MINOR );
 
     i_wallclock = mdate();
 
@@ -910,7 +910,7 @@ static void FrontendSet( bool b_init )
         break;
 
     case FE_QPSK:
-        if ( psz_modulation != NULL )
+        if (( psz_modulation != NULL ) && i_dvbs2)
         {
             p = &dvbs2_cmdseq;
             p->props[MODULATION].u.data = GetModulation();
@@ -925,9 +925,9 @@ static void FrontendSet( bool b_init )
         p->props[FEC_INNER].u.data = GetFECInner(info.caps);
         p->props[FREQUENCY].u.data = FrontendDoDiseqc();
 
-        msg_Dbg( NULL, "tuning QPSK frontend to f=%d srate=%d inversion=%d fec=%d rolloff=%d modulation=%s pilot=%d",
+        msg_Dbg( NULL, "tuning QPSK frontend to f=%d srate=%d inversion=%d fec=%d rolloff=%d modulation=%s pilot=%d delivery system=%s",
                  i_frequency, i_srate, i_inversion, i_fec, i_rolloff,
-                 psz_modulation == NULL ? "legacy" : psz_modulation, i_pilot );
+                 psz_modulation == NULL ? "legacy" : psz_modulation, i_pilot, i_dvbs2 ? "DVB-S2" : "DVB-S");
         break;
 
     case FE_ATSC:
@@ -957,7 +957,7 @@ static void FrontendSet( bool b_init )
     }
 
     /* Now send it all to the frontend device */
-    if ( ioctl( i_frontend, FE_SET_PROPERTY, p ) < 0 )
+    if ( ioctl( i_frontend, FE_SET_PROPERTY, p ) < 0 ) 
     {
         msg_Err( NULL, "setting frontend failed (%s)", strerror(errno) );
         exit(1);
diff --git a/dvblast.1 b/dvblast.1
index 189d171..7647798 100644
--- a/dvblast.1
+++ b/dvblast.1
@@ -148,7 +148,7 @@ When locked, quit after this delay (in ms), or after the first lock timeout
 Remote socket to use
 .TP
 \fB\-R\fR, \fB\-\-rolloff\fR <rolloff>
-Rolloff value to use
+Rolloff value to use. When Rolloff parameter used it wil distinguish between DVB-S and DVB-S2. 
 .br
 DVB-S2 35=0.35|25=0.25|20=0.20|0=AUTO (default: 35)
 .TP
diff --git a/dvblast.c b/dvblast.c
index a0e6a5d..8f80582 100644
--- a/dvblast.c
+++ b/dvblast.c
@@ -67,6 +67,7 @@ int i_inversion = -1;
 int i_srate = 27500000;
 int i_fec = 999;
 int i_rolloff = 35;
+bool i_dvbs2 = false; 
 int i_satnum = 0;
 int i_voltage = 13;
 int b_tone = 0;
@@ -677,6 +678,7 @@ int main( int i_argc, char **pp_argv )
 
         case 'R':
             i_rolloff = strtol( optarg, NULL, 0 );
+            i_dvbs2 = true; 
             break;
 
         case 's':
@@ -709,6 +711,7 @@ int main( int i_argc, char **pp_argv )
 
         case 'P':
             i_pilot = strtol( optarg, NULL, 0 );
+            i_dvbs2 = true; 
             break;
 
         case 'K':
diff --git a/dvblast.h b/dvblast.h
index 40ce4c4..1b55ecc 100644
--- a/dvblast.h
+++ b/dvblast.h
@@ -161,6 +161,7 @@ extern int i_srate;
 extern int i_satnum;
 extern int i_fec;
 extern int i_rolloff;
+extern bool i_dvbs2;
 extern int i_voltage;
 extern int b_tone;
 extern int i_bandwidth;
-- 
1.7.2.5

